<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=ar
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'منتدى SPIP (الخاص والعمومي)',
	'forum_slogan' => 'إدارة المنتديات الخاصة والعمومي في SPIP',
];
